const fs = require('fs-extra');
const path = require('path');
const theo = require('theo');
const glob = require('glob');

// Register custom formats
require('../../src/formats/custom-props');
require('../../src/formats/register-props');

const root = path.resolve(__dirname, '../../');
const buildDir = path.resolve(root, '.build/');

const formats = [
  {
    format: 'json',
    transform: 'web',
  },
  {
    format: 'common.js',
    transform: 'web',
  },
  {
    format: 'module.js',
    transform: 'web',
  },
  {
    format: 'custom-props.css',
    transform: 'raw',
  },
  {
    format: 'raw.json',
    transform: 'raw',
  },
  {
    format: 'register-props.js',
    transform: 'raw',
  },
];

glob(path.resolve(root, 'src/props/*.json'), (err, data) => {
  if (err) throw err;
  data.map((file) => {
    const name = path.parse(file).name;
    return formats.map((type) => {
      return theo
        .convert({
          transform: {
            type: type.transform,
            file: file,
          },
          format: {
            type: type.format,
          },
          resolveMetaAliases: true,
        })
        .then((data) => {
          fs.outputFile(path.resolve(buildDir, `${name}.${type.format}`), data, (err) => {
            if (err) return console.error(err);
            console.log(`${name}.${type.format} saved to ${buildDir}`);
          });
        })
        .catch((error) => console.error(`Something went wrong: ${error} in ${file}`));
    });
  });
});
